@@ -182,7 +182,7 @@ class JunosDevice(linux.LinuxDevice):
             tnp_addr: tnp address to execute, if not execut the command on
                       every SPU.
         '''
-        spus = kwargs.get("tnp_addr", False) and [kwargs["tnp_addr"]] or self["spus"]
+        spus = kwargs.get("tnp_addr", None) and [kwargs["tnp_addr"]] or self["spus"]
 
         linux.LinuxDevice.cmd(self, "run start shell csh",
                 expect = self.original_prompt, timeout = 3, with_log = False)
@@ -648,9 +648,9 @@ class JunosDevice(linux.LinuxDevice):
         # dynamic-application
         if isinstance(dynamic_application, list):
             for dynapp in dynamic_application:
-                self.configure(common_part +  "match application %s" %(dynapp))
+                self.configure(common_part +  "match dynamic-application %s" %(dynapp))
         elif dynamic_application:
-            self.configure(common_part +  "match application %s" %(dynamic_application))
+            self.configure(common_part +  "match dynamic-application %s" %(dynamic_application))
 
         # action
         action_line = common_part + "then "
